@@ -267,7 +267,7 @@ class DataSetsManager(ManagerMix):
     #     return json.dumps(out)
 
     def create_data_set(self, station, element_code, aggregation, time_step_code, level_code, data_set_type="TECHNICAL", elementMarkOverride = None, description = None):
-        element_context = self._client._element_contexts_manager.element_context_by_element(element_code, aggregation, time_step_code)
+        element_context = self._client._element_contexts_manager.element_context_by_element(element_code, aggregation, time_step_code, level_code)
 
         url = station.url + "/data-sets"
 
