@@ -38,5 +38,5 @@ class Site:
     def data_sets(self):
         return self._client._data_sets_manager.data_sets(self.url, site=self)
 
-    def data_set_by_code(self, element, aggregation, time_step, level=None):
-        return self._client._data_sets_manager.data_set_by_code(self, element, aggregation, time_step, level)
+    def data_set_by_code(self, element, aggregation, time_step, level=None, elementMarkOverride = None):
+        return self._client._data_sets_manager.data_set_by_code(self, element, aggregation, time_step, level, elementMarkOverride)
